emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/realgud c5d52ff 131/140: Add breakpoint-all regexps for


From: Rocky Bernstein
Subject: [elpa] externals/realgud c5d52ff 131/140: Add breakpoint-all regexps for most debuggers
Date: Sat, 25 May 2019 19:35:49 -0400 (EDT)

branch: externals/realgud
commit c5d52ff4e9fdd89e94933bf2377bff3e4950f026
Author: rocky <address@hidden>
Commit: rocky <address@hidden>

    Add breakpoint-all regexps for most debuggers
---
 realgud.el                         |  2 +-
 realgud/common/buffer/backtrace.el | 16 ++++++-------
 realgud/debugger/ipdb/init.el      | 44 +++++++++++++++++++++++++---------
 realgud/debugger/ipdb/ipdb.el      |  4 +++-
 realgud/debugger/jdb/init.el       |  2 ++
 realgud/debugger/pdb/init.el       | 49 ++++++++++++++++++++++++++++----------
 realgud/debugger/perldb/init.el    | 27 +++++++++++----------
 realgud/debugger/remake/init.el    |  8 +++----
 realgud/debugger/trepanjs/init.el  |  9 +++----
 realgud/lang/js.el                 | 28 ++++++++++++++++++++--
 10 files changed, 132 insertions(+), 57 deletions(-)

diff --git a/realgud.el b/realgud.el
index 53bd589..9bb4382 100644
--- a/realgud.el
+++ b/realgud.el
@@ -7,7 +7,7 @@
 ;; URL: http://github.com/realgud/realgud/
 ;; Keywords: gdb, python, perl, go, bash, nodejs, zsh, bashdb, zshdb, remake, 
make, trepan, perldb, pdb
 
-;; Copyright (C) 2015-2018 Free Software Foundation, Inc
+;; Copyright (C) 2015-2019 Free Software Foundation, Inc
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
diff --git a/realgud/common/buffer/backtrace.el 
b/realgud/common/buffer/backtrace.el
index fe597d4..3b9b8b8 100644
--- a/realgud/common/buffer/backtrace.el
+++ b/realgud/common/buffer/backtrace.el
@@ -105,14 +105,14 @@
        (process)
        )
     (with-current-buffer-safe cmdbuf
-      (let ((frame-pat (realgud-cmdbuf-pat "debugger-backtrace"))
+      (let ((backtrace-pat (realgud-cmdbuf-pat "debugger-backtrace"))
            (indicator-re (or (realgud-cmdbuf-pat "selected-frame-indicator")
                              "->"))
            (selected-frame-num)
            (frame-pos-ring)
            (sleep-count 0)
            )
-       (unless frame-pat
+       (unless backtrace-pat
          (error "No 'debugger-backtrace' regular expression recorded for 
debugger %s"
                 (realgud-cmdbuf-debugger-name)))
        (setq process (get-buffer-process (current-buffer)))
@@ -142,7 +142,7 @@
              (if divert-string
                  (let* ((triple
                          (realgud:backtrace-add-text-properties
-                          frame-pat cmdbuf divert-string indicator-re))
+                          backtrace-pat cmdbuf divert-string indicator-re))
                         (string-with-props
                          (ansi-color-filter-apply (car triple)))
                         (frame-num-pos-list (cl-caddr triple))
@@ -385,7 +385,7 @@ non-digit will start entry number from the beginning again."
       (setq realgud-goto-entry-acc ""))
   (realgud-goto-frame-n-internal (this-command-keys)))
 
-(defun realgud:backtrace-add-text-properties(frame-pat cmdbuf &optional 
opt-string
+(defun realgud:backtrace-add-text-properties(backtrace-pat cmdbuf &optional 
opt-string
                                                       frame-indicator-re)
   "Parse OPT-STRING or the current buffer and add frame properties: frame 
number,
 filename, line number, whether the frame is selected as text properties."
@@ -394,10 +394,10 @@ filename, line number, whether the frame is selected as 
text properties."
                    (buffer-substring (point-min) (point-max))
                    ))
         (stripped-string (ansi-color-filter-apply string))
-        (frame-regexp (realgud-loc-pat-regexp frame-pat))
-        (frame-group-pat (realgud-loc-pat-num frame-pat))
-        (file-group-pat (realgud-loc-pat-file-group frame-pat))
-        (line-group-pat (realgud-loc-pat-line-group frame-pat))
+        (frame-regexp (realgud-loc-pat-regexp backtrace-pat))
+        (frame-group-pat (realgud-loc-pat-num backtrace-pat))
+        (file-group-pat (realgud-loc-pat-file-group backtrace-pat))
+        (line-group-pat (realgud-loc-pat-line-group backtrace-pat))
         (alt-frame-num -1)
         (last-pos 0)
         (selected-frame-num nil)
diff --git a/realgud/debugger/ipdb/ipdb.el b/realgud/debugger/ipdb/ipdb.el
index 23ba2ad..a17a041 100644
--- a/realgud/debugger/ipdb/ipdb.el
+++ b/realgud/debugger/ipdb/ipdb.el
@@ -1,4 +1,4 @@
-;; Copyright (C) 2016 Free Software Foundation, Inc
+;; Copyright (C) 2016, 2019 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <address@hidden>
 ;; Author: Sean Farley <address@hidden>
@@ -29,6 +29,8 @@
   :group 'realgud
   :version "24.3")
 
+(declare-function make-realgud-loc "realgud-loc" (a b c d e f))
+
 ;; -------------------------------------------------------------------
 ;; User-definable variables
 ;;
diff --git a/realgud/debugger/jdb/init.el b/realgud/debugger/jdb/init.el
index 39aada7..b344820 100644
--- a/realgud/debugger/jdb/init.el
+++ b/realgud/debugger/jdb/init.el
@@ -226,6 +226,8 @@ backtrace listing.")
 (setf (gethash "clear"       realgud:jdb-command-hash) "*not-implemented*")
 (setf (gethash "restart"     realgud:jdb-command-hash) "*not-implemented*")
 
+(setf (gethash "info-breakpoints" realgud:jdb-command-hash) "clear")
+
 (setf (gethash "continue"    realgud:jdb-command-hash) "cont")
 (setf (gethash "finish"      realgud:jdb-command-hash) "step up")
 (setf (gethash "up"          realgud:jdb-command-hash) "up\C-Mwhere")
diff --git a/realgud/debugger/perldb/init.el b/realgud/debugger/perldb/init.el
index 42dbedf..ee18e0c 100644
--- a/realgud/debugger/perldb/init.el
+++ b/realgud/debugger/perldb/init.el
@@ -1,4 +1,4 @@
-;;; Copyright (C) 2011, 2014-2016 Free Software Foundation, Inc
+;;; Copyright (C) 2011, 2014-2016, 2019 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <address@hidden>
 ;; This program is free software; you can redistribute it and/or modify
@@ -121,18 +121,19 @@ realgud-loc-pat struct")
 
 (setf (gethash "perldb"  realgud-pat-hash) realgud:perldb-pat-hash)
 
-(setf (gethash "backtrace" realgud:perldb-command-hash) "T")
-(setf (gethash "break"     realgud:perldb-command-hash) "b %l")
-(setf (gethash "clear"     realgud:perldb-command-hash) "B %l")
-(setf (gethash "continue"  realgud:perldb-command-hash) "c")
-(setf (gethash "eval"      realgud:perldb-command-hash) "x %s")
-(setf (gethash "quit"      realgud:perldb-command-hash) "q")
-(setf (gethash "restart"   realgud:perldb-command-hash) "R")
-(setf (gethash "run"       realgud:perldb-command-hash) "R")
-(setf (gethash "step"      realgud:perldb-command-hash) "s")
-(setf (gethash "next"      realgud:perldb-command-hash) "n")
-(setf (gethash "until"     realgud:perldb-command-hash) "c %l")
-(setf (gethash "perldb" realgud-command-hash) realgud:perldb-command-hash)
+(setf (gethash "backtrace"        realgud:perldb-command-hash) "T")
+(setf (gethash "break"            realgud:perldb-command-hash) "b %l")
+(setf (gethash "clear"            realgud:perldb-command-hash) "B %l")
+(setf (gethash "continue"         realgud:perldb-command-hash) "c")
+(setf (gethash "eval"             realgud:perldb-command-hash) "x %s")
+(setf (gethash "info-breakpoints" realgud:perldb-command-hash) "L")
+(setf (gethash "quit"             realgud:perldb-command-hash) "q")
+(setf (gethash "restart"          realgud:perldb-command-hash) "R")
+(setf (gethash "run"              realgud:perldb-command-hash) "R")
+(setf (gethash "step"             realgud:perldb-command-hash) "s")
+(setf (gethash "next"             realgud:perldb-command-hash) "n")
+(setf (gethash "until"            realgud:perldb-command-hash) "c %l")
+(setf (gethash "perldb"           realgud-command-hash) 
realgud:perldb-command-hash)
 
 ;; Unsupported features:
 (setf (gethash "frame" realgud:perldb-command-hash) "*not-implemented*")
diff --git a/realgud/debugger/remake/init.el b/realgud/debugger/remake/init.el
index 1122d08..0158e98 100644
--- a/realgud/debugger/remake/init.el
+++ b/realgud/debugger/remake/init.el
@@ -122,15 +122,14 @@ backtrace listing.")
 
 (setf (gethash "debugger-breakpoint" realgud:remake-pat-hash)
   (make-realgud-loc-pat
-   :regexp (format "^%s[ \t]+\\(breakpoint\\)[ \t]+\\(keep\\|del\\)[ 
\t]+\\([yn]\\)[ \t]+.\\(0x??\\) \\(.+\\):%s"
+   :regexp (format "^[ \t]*%s[ \t]+\\(breakpoint\\)[ \t]+\\(keep\\|del\\)[ 
\t]+\\([yn]\\)[ \t]+\\(0x??\\).* at \\(.+\\):%s"
                   realgud:regexp-captured-num realgud:regexp-captured-num)
    :num 1
    :text-group 2  ;; misnamed Is "breakpoint" or "watchpoint"
    :string 3      ;; misnamed. Is "keep" or "del"
-   ;; Enable is missing
    ;; Skipped mask
-   :file-group 5
-   :line-group 6)
+   :file-group 6
+   :line-group 7)
   )
 
 
@@ -183,6 +182,7 @@ backtrace listing.")
 
 (setf (gethash "break"  realgud:remake-command-hash) "break %l")
 (setf (gethash "eval"   realgud:remake-command-hash) "expand %s")
+(setf (gethash "info-breakpoints" realgud:remake-command-hash) "info 
breakpoints")
 (setf (gethash "remake" realgud-command-hash) realgud:remake-command-hash)
 
 ;; Unsupported features:
diff --git a/realgud/debugger/trepanjs/init.el 
b/realgud/debugger/trepanjs/init.el
index 765472c..4f02a17 100644
--- a/realgud/debugger/trepanjs/init.el
+++ b/realgud/debugger/trepanjs/init.el
@@ -1,4 +1,4 @@
-;; Copyright (C) 2015-2016, 2018 Free Software Foundation, Inc
+;; Copyright (C) 2015-2016, 2018, 2019 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <address@hidden>
 
@@ -153,10 +153,11 @@ realgud-loc-pat struct")
 ;; We need aliases for step and next because the default would
 ;; do step 1 and trepanjs doesn't handle this. Or when it does,
 ;; it will probably look like step(1)
-(setf (gethash "eval"       realgud:trepanjs-command-hash) "eval(%q)")
-(setf (gethash "quit"       realgud:trepanjs-command-hash) "quit()")
+(setf (gethash "eval"             realgud:trepanjs-command-hash) "eval(%q)")
+(setf (gethash "info-breakpoints" realgud:trepanjs-command-hash) 
"info('breakpoints')")
+(setf (gethash "quit"             realgud:trepanjs-command-hash) "quit()")
 
 ;; Unsupported features:
-(setf (gethash "kill"  realgud:trepanjs-command-hash) "*not-implemented*")
+(setf (gethash "kill"             realgud:trepanjs-command-hash) 
"*not-implemented*")
 
 (provide-me "realgud:trepanjs-")
diff --git a/realgud/lang/js.el b/realgud/lang/js.el
index 4ebd2bd..71260d4 100644
--- a/realgud/lang/js.el
+++ b/realgud/lang/js.el
@@ -1,4 +1,4 @@
-;; Copyright (C) 2015-2016, 2018 Free Software Foundation, Inc
+;; Copyright (C) 2015-2016, 2018-2019 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <address@hidden>
 
@@ -31,7 +31,7 @@
 
 (declare-function realgud-goto-line-for-pt 'realgud-track)
 
-;;  Regular expression that describes a Perl Carp backtrace line.
+;;  Regular expression that describes a javascript backtrace line.
 ;;  at /tmp/foo.pl line 7
 ;;     main::__ANON__('Illegal division by zero at /tmp/foo.pl line 4.\x{a}') 
called at /tmp/foo.pl line 4
 ;;     main::foo(3) called at /tmp/foo.pl line 8
@@ -44,6 +44,30 @@
    :char-offset-group 4)
   "A realgud-loc-pat struct that describes a V8 backtrace location")
 
+;;  Regular expression that describes a javascript backtrace line.
+;; For example:
+;;   1 breakpoint y   /usr/local/lib/node_modules/trepanjs/bin/trepanjs:1
+;;     breakpoint already hit 1 time
+;;   2 breakpoint y   /usr/local/lib/node_modules/trepanjs/bin/trepanjs:5
+;    3 breakpoint y   /usr/local/lib/node_modules/trepanjs/bin/trepanjs:6
+(defconst realgud:js-debugger-backtrace-pat
+  (make-realgud-loc-pat
+   :regexp (format "^%s[ \t]+\\(breakpoint\\)[ \t]+\\([yn]\\)[ \t]+.*at 
\\(.+\\):%s"
+                  realgud:regexp-captured-num realgud:regexp-captured-num)
+   :num 1
+   :text-group 2  ;; misnamed Is "breakpoint" or "watchpoint"
+   :string 3      ;; misnamed. Is "y/n"
+   :file-group 4
+   :line-group 5)
+  "A realgud-loc-pat struct that describes a V8 breakpoint location")
+
+(defconst realgud:js-file-line-loc-pat
+  (make-realgud-loc-pat
+   :regexp (format "^\\([^:]+\\):%s" realgud:regexp-captured-num)
+   :file-group 1
+   :line-group 2)
+  "A realgud-loc-pat struct that describes a V8 file/line location")
+
 (defconst realgud:js-file-line-loc-pat
   (make-realgud-loc-pat
    :regexp (format "^\\([^:]+\\):%s" realgud:regexp-captured-num)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/realgud/debugger/ipdb/init.el b/realgud/debugger/ipdb/init.el
index 10786db..187f805 100644
--- a/realgud/debugger/ipdb/init.el
+++ b/realgud/debugger/ipdb/init.el
@@ -1,4 +1,4 @@
-;; Copyright (C) 2016, 2018 Free Software Foundation, Inc
+;; Copyright (C) 2016, 2018-2019 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <address@hidden>
 ;; Author: Sean Farley <address@hidden>
@@ -15,7 +15,7 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
-;; Stock Python debugger ipdb
+;; ipdb: "interactive" debugger extension to Python debugger pdb
 
 (eval-when-compile (require 'cl-lib))   ;For setf.
 
@@ -36,6 +36,10 @@ realgud-loc-pat struct")
 
 (declare-function make-realgud-loc "realgud-loc" (a b c d e f))
 
+;; -------------------------------------------------------------------
+;; User-definable variables
+;;
+
 ;; realgud-loc-pat that describes a ipdb location generally shown
 ;; before a command prompt.
 ;;
@@ -66,11 +70,27 @@ realgud-loc-pat struct")
 (setf (gethash "lang-backtrace" realgud:ipdb-pat-hash)
       realgud-python-backtrace-loc-pat)
 
+(setf (gethash "debugger-backtrace" realgud:ipdb-pat-hash)
+      realgud:python-trepan-backtrace-pat)
+
+;;  realgud-loc-pat that describes a line a Python "info break" line.
+;; For example:
+;; 1   breakpoint    keep y   at /usr/local/bin/trepan3k:7
+(setf (gethash "debugger-breakpoint" realgud:ipdb-pat-hash)
+  (make-realgud-loc-pat
+   :regexp (format "^%s[ \t]+\\(breakpoint\\)[ \t]+\\(keep\\|del\\)[ 
\t]+\\(yes\\|no\\)[ \t]+.*at \\(.+\\):%s"
+                  realgud:regexp-captured-num realgud:regexp-captured-num)
+   :num 1
+   :text-group 2  ;; misnamed Is "breakpoint" or "watchpoint"
+   :string 3      ;; misnamed. Is "keep" or "del"
+   :file-group 5
+   :line-group 6))
+
 ;;  realgud-loc-pat that describes location in a pytest error
 (setf (gethash "pytest-error" realgud:ipdb-pat-hash)
       realgud-pytest-error-loc-pat)
 
 ;;  Regular expression that describes location in a flake8 message
 (setf (gethash "flake8-msg" realgud:ipdb-pat-hash)
       realgud-flake8-msg-loc-pat)
 
@@ -126,19 +146,21 @@ realgud-loc-pat struct")
   "Hash key is command name like 'finish' and the value is
 the ipdb command to use, like 'return'")
 
-(setf (gethash "ipdb" realgud-command-hash) realgud:ipdb-command-hash)
-
 ;; Mappings between ipdb-specific names and GUD names
-(setf (gethash "finish" realgud:ipdb-command-hash) "return")
-(setf (gethash "kill" realgud:ipdb-command-hash) "quit")
-(setf (gethash "backtrace" realgud:ipdb-command-hash) "where")
+(setf (gethash "finish"           realgud:ipdb-command-hash) "return")
+(setf (gethash "kill"             realgud:ipdb-command-hash) "quit")
+(setf (gethash "backtrace"        realgud:ipdb-command-hash) "where")
 ;; Clear in Python does both the usual “delete” and “clear”
-(setf (gethash "delete" realgud:ipdb-command-hash) "clear %p")
-(setf (gethash "clear" realgud:ipdb-command-hash) "clear %X:%l")
-(setf (gethash "eval" realgud:ipdb-command-hash) "pp %s")
+(setf (gethash "delete"           realgud:ipdb-command-hash) "clear %p")
+(setf (gethash "clear"            realgud:ipdb-command-hash) "clear %X:%l")
+;; Use ‘!’ instead of ‘p’, since ‘p’ only works for expressions, not statements
+(setf (gethash "eval"             realgud:ipdb-command-hash) "pp %s")
+(setf (gethash "info-breakpoints" realgud:ipdb-command-hash) "break")
 
 ;; Unsupported features:
 (setf (gethash "shell" realgud:ipdb-command-hash) "*not-implemented*")
 (setf (gethash "frame" realgud:ipdb-command-hash) "*not-implemented*")
 
+(setf (gethash "ipdb" realgud-command-hash) realgud:ipdb-command-hash)
+
 (provide-me "realgud:ipdb-")
@@ -66,11 +70,27 @@ realgud-loc-pat struct")
       realgud-pytest-error-loc-pat)
 
-;;  Regular expression that describes location in a flake8 message
+;;  realgud-loc-pat that describes location in a flake8 message
 (setf (gethash "flake8-msg" realgud:ipdb-pat-hash)
       realgud-flake8-msg-loc-pat)
diff --git a/realgud/debugger/pdb/init.el b/realgud/debugger/pdb/init.el
index 064d29f..b6e702f 100644
--- a/realgud/debugger/pdb/init.el
+++ b/realgud/debugger/pdb/init.el
@@ -1,4 +1,4 @@
-;; Copyright (C) 2015-2016, 2018 Free Software Foundation, Inc
+;; Copyright (C) 2015-2016, 2018-2019 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <address@hidden>
 
@@ -35,6 +35,10 @@ realgud-loc-pat struct")
 
 (declare-function make-realgud-loc "realgud-loc" (a b c d e f))
 
+;; -------------------------------------------------------------------
+;; User-definable variables
+;;
+
 ;; Regular expression that describes a pdb location generally shown
 ;; before a command prompt.
 ;;
@@ -61,15 +65,31 @@ realgud-loc-pat struct")
        :regexp   "^[(]+Pdb[)]+ "
        ))
 
 ;;  Regular expression that describes a Python backtrace line.
 (setf (gethash "lang-backtrace" realgud:pdb-pat-hash)
       realgud-python-backtrace-loc-pat)
 
-;;  Regular expression that describes location in a pytest error
+(setf (gethash "debugger-backtrace" realgud:pdb-pat-hash)
+      realgud:python-trepan-backtrace-pat)
+
+;;  realgud-loc-pat that describes a line a Python "info break" line.
+;; For example:
+;; 1   breakpoint    keep y   at /usr/local/bin/trepan3k:7
+(setf (gethash "debugger-breakpoint" realgud:pdb-pat-hash)
+  (make-realgud-loc-pat
+   :regexp (format "^%s[ \t]+\\(breakpoint\\)[ \t]+\\(keep\\|del\\)[ 
\t]+\\(yes\\|no\\)[ \t]+.*at \\(.+\\):%s"
+                  realgud:regexp-captured-num realgud:regexp-captured-num)
+   :num 1
+   :text-group 2  ;; misnamed Is "breakpoint" or "watchpoint"
+   :string 3      ;; misnamed. Is "keep" or "del"
+   :file-group 5
+   :line-group 6))
+
+;;  realgud-loc-pat that describes location in a pytest error
 (setf (gethash "pytest-error" realgud:pdb-pat-hash)
       realgud-pytest-error-loc-pat)
 
 ;;  Regular expression that describes location in a flake8 message
 (setf (gethash "flake8-msg" realgud:pdb-pat-hash)
       realgud-flake8-msg-loc-pat)
 
@@ -82,7 +102,7 @@ realgud-loc-pat struct")
        :file-group 2
        :line-group 3))
 
 ;;  Regular expression that describes a "delete breakpoint" line
 ;; Python 3 includes a file name and line number; Python 2 doesn't
 (setf (gethash "brkpt-del" realgud:pdb-pat-hash)
       (make-realgud-loc-pat
@@ -119,8 +139,8 @@ realgud-loc-pat struct")
        ;;  (0 pdb-frames-current-frame-face append))
        ))
 
-(setf (gethash "pdb" realgud-pat-hash) realgud:pdb-pat-hash)
-
+(setf (gethash "font-lock-breakpoint-keywords" realgud:pdb-pat-hash)
+      realgud:python-debugger-font-lock-breakpoint-keywords)
 
 (defvar realgud:pdb-command-hash (make-hash-table :test 'equal)
   "Hash key is command name like 'finish' and the value is
@@ -129,17 +149,20 @@ the pdb command to use, like 'return'")
 (setf (gethash "pdb" realgud-command-hash) realgud:pdb-command-hash)
 
 ;; Mappings between PDB-specific names and GUD names
-(setf (gethash "finish" realgud:pdb-command-hash) "return")
-(setf (gethash "kill" realgud:pdb-command-hash) "quit")
-(setf (gethash "backtrace" realgud:pdb-command-hash) "where")
+(setf (gethash "finish"           realgud:pdb-command-hash) "return")
+(setf (gethash "kill"             realgud:pdb-command-hash) "quit")
+(setf (gethash "backtrace"        realgud:pdb-command-hash) "where")
 ;; Clear in Python does both the usual “delete” and “clear”
-(setf (gethash "delete" realgud:pdb-command-hash) "clear %p")
-(setf (gethash "clear" realgud:pdb-command-hash) "clear %X:%l")
+(setf (gethash "delete"           realgud:pdb-command-hash) "clear %p")
+(setf (gethash "clear"            realgud:pdb-command-hash) "clear %X:%l")
 ;; Use ‘!’ instead of ‘p’, since ‘p’ only works for expressions, not statements
-(setf (gethash "eval" realgud:pdb-command-hash) "!%s")
+(setf (gethash "eval"             realgud:pdb-command-hash) "!%s")
+(setf (gethash "info-breakpoints" realgud:pdb-command-hash) "break")
 
 ;; Unsupported features:
 (setf (gethash "shell" realgud:pdb-command-hash) "*not-implemented*")
 (setf (gethash "frame" realgud:pdb-command-hash) "*not-implemented*")
 
+(setf (gethash "pdb" realgud-pat-hash) realgud:pdb-pat-hash)
+
 (provide-me "realgud:pdb-")
@@ -61,15 +65,31 @@ realgud-loc-pat struct")
        ))
 
-;;  Regular expression that describes a Python backtrace line.
+;; realgud-loc-pat that describes a Python backtrace line.
 (setf (gethash "lang-backtrace" realgud:pdb-pat-hash)
       realgud-python-backtrace-loc-pat)
@@ -61,15 +65,31 @@ realgud-loc-pat struct")
       realgud-pytest-error-loc-pat)
 
-;;  Regular expression that describes location in a flake8 message
+;;  realgud-loc-pat that describes location in a flake8 message
 (setf (gethash "flake8-msg" realgud:pdb-pat-hash)
       realgud-flake8-msg-loc-pat)
@@ -82,7 +102,7 @@ realgud-loc-pat struct")
        :line-group 3))
 
-;;  Regular expression that describes a "delete breakpoint" line
+;; realgud-loc-pat that describes a "delete breakpoint" line
 ;; Python 3 includes a file name and line number; Python 2 doesn't
 (setf (gethash "brkpt-del" realgud:pdb-pat-hash)